Polishing extensions
====================

.. toctree::

    plumbery.polishers.ansible
    plumbery.polishers.configure
    plumbery.polishers.information
    plumbery.polishers.inventory
    plumbery.polishers.ping
    plumbery.polishers.prepare

